--
local function copyTable(table) -- Copies a table and all its subtables
    if type(table) ~= "table" then error(2, "expected table, got "..type(table)) end
    local meta = getmetatable(table)
    local target = {}
    for k, v in pairs(table) do
        if type(v) == "table" then
            target[k] = copyTable(v)
        else
            target[k] = v
        end
    end
    setmetatable(target, meta)
    return target
end
rawset(_G, "copyTable", copyTable)

local function sanitizeText(txt)
	--print("SUBM "..txt)
	txt = string.gsub(txt, "(%^%d)", "")
	txt = string.gsub(txt, "(\n)", "")
	--print("FORM "..txt)
	return txt
end
rawset(_G, "sanitizeText", sanitizeText)

local function LaunchRelative(mo, hangle, vangle, speed)
    local cx,cy,cz
    cx = FixedMul( FixedMul( speed, cos(hangle) ), cos(vangle) )
    cy = FixedMul( FixedMul( speed, sin(hangle) ), cos(vangle) )
    cz = FixedMul(           speed, sin(vangle) )
    mo.momx = $+cx
    mo.momy = $+cy
    mo.momz = $+cz
end
rawset(_G, "LaunchRelative", LaunchRelative)